==> mailjet-client-4.5.0-sources.jar: com/mailjet/client/resource/Campaigndraft.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;

/**
 *
 * @author Guillaume Badi
 */
public class Campaigndraft {

    public static Resource resource = new Resource("campaigndraft", "");

	public static String AXFRACTIONNAME = "AXFractionName";
	public static String AXTESTING = "AXTesting";
	public static String CAMPAIGN = "Campaign";
	public static String CONTACTSLIST = "ContactsList";
	public static String CREATEDAT = "CreatedAt";
	public static String CURRENT = "Current";
	public static String DELIVEREDAT = "DeliveredAt";
	public static String EDITMODE = "EditMode";
	public static String ID = "ID";
	public static String ISSTARRED = "IsStarred";
	public static String ISTEXTPARTINCLUDED = "IsTextPartIncluded";
	public static String LOCALE = "Locale";
	public static String MODIFIEDAT = "ModifiedAt";
	public static String PRESET = "Preset";
	public static String REPLYEMAIL = "ReplyEmail";
	public static String SEGMENTATION = "Segmentation";
	public static String SENDER = "Sender";
	public static String SENDEREMAIL = "SenderEmail";
	public static String SENDERNAME = "SenderName";
	public static String STATUS = "Status";
	public static String SUBJECT = "Subject";
	public static String TEMPLATE = "Template";
	public static String TITLE = "Title";
	public static String URL = "Url";
	public static String USED = "Used";
	public static String ISARCHIVED = "IsArchived";
	public static String ISCAMPAIGN = "IsCampaign";
	public static String ISDELETED = "IsDeleted";
	public static String ISHANDLED = "IsHandled";
	public static String MODIFIED = "Modified";
	public static String NEWSLETTERTEMPLATE = "NewsLetterTemplate";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}

==> mailjet-client-5.2.0-sources.jar: com/mailjet/client/resource/Campaigndraft.java <==

/*
 * This is a generated class.
 */

package com.mailjet.client.resource;

import com.mailjet.client.Resource;
import com.mailjet.client.enums.ApiAuthenticationType;
import com.mailjet.client.enums.ApiVersion;

/**
 *
 * @author Guillaume Badi
 */
public class Campaigndraft {

    public static Resource resource = new Resource("campaigndraft", "", ApiVersion.V3, ApiAuthenticationType.Basic);

	public static String AXFRACTIONNAME = "AXFractionName";
	public static String AXTESTING = "AXTesting";
	public static String CAMPAIGN = "Campaign";
	public static String CONTACTSLIST = "ContactsList";
	public static String CREATEDAT = "CreatedAt";
	public static String CURRENT = "Current";
	public static String DELIVEREDAT = "DeliveredAt";
	public static String EDITMODE = "EditMode";
	public static String ID = "ID";
	public static String ISSTARRED = "IsStarred";
	public static String ISTEXTPARTINCLUDED = "IsTextPartIncluded";
	public static String LOCALE = "Locale";
	public static String MODIFIEDAT = "ModifiedAt";
	public static String PRESET = "Preset";
	public static String REPLYEMAIL = "ReplyEmail";
	public static String SEGMENTATION = "Segmentation";
	public static String SENDER = "Sender";
	public static String SENDEREMAIL = "SenderEmail";
	public static String SENDERNAME = "SenderName";
	public static String STATUS = "Status";
	public static String SUBJECT = "Subject";
	public static String TEMPLATE = "Template";
	public static String TITLE = "Title";
	public static String URL = "Url";
	public static String USED = "Used";
	public static String ISARCHIVED = "IsArchived";
	public static String ISCAMPAIGN = "IsCampaign";
	public static String ISDELETED = "IsDeleted";
	public static String ISHANDLED = "IsHandled";
	public static String MODIFIED = "Modified";
	public static String NEWSLETTERTEMPLATE = "NewsLetterTemplate";
	public static String LIMIT = "Limit";
	public static String OFFSET = "Offset";
	public static String COUNTONLY = "CountOnly";

}
